@@ -86,6 +86,12 @@
 #'   geom_smooth(se = FALSE) +
 #'   geom_point()
 #' qplot(.hat, .cooksd, size = .cooksd / .hat, data = au) + scale_size_area()
+#' 
+#' # column-wise models
+#' a <- matrix(rnorm(20), nrow = 10)
+#' b <- a + rnorm(length(a))
+#' result <- lm(b ~ a)
+#' tidy(result)
 NULL
 
 
@@ -100,6 +106,9 @@ NULL
 #' @details If \code{conf.int=TRUE}, the confidence interval is computed with
 #' the \code{\link{confint}} function.
 #' 
+#' While \code{tidy} is supported for "mlm" objects, \code{augment} and
+#' \code{glance} are not.
+#' 
 #' @return \code{tidy.lm} returns one row for each coefficient, with five columns:
 #'   \item{term}{The term in the linear model being estimated and tested}
 #'   \item{estimate}{The estimated coefficient}
@@ -107,37 +116,31 @@ NULL
 #'   \item{statistic}{t-statistic}
 #'   \item{p.value}{two-sided p-value}
 #' 
-#' If \code{cont.int=TRUE}, it also includes columns for \code{conf.low} and
+#' If the linear model is an "mlm" object (multiple linear model), there is an
+#' additional column:
+#'   \item{response}{Which response column the coefficients correspond to
+#'   (typically Y1, Y2, etc)}
+#' 
+#' If \code{conf.int=TRUE}, it also includes columns for \code{conf.low} and
 #' \code{conf.high}, computed with \code{\link{confint}}.
 #' 
 #' @export
-tidy.lm <- function(x, conf.int=FALSE, conf.level=.95,
-                    exponentiate=FALSE, ...) {
+tidy.lm <- function(x, conf.int = FALSE, conf.level = .95,
+                    exponentiate = FALSE, ...) {
     co <- coef(summary(x))
-    nn <- c("estimate", "std.error", "statistic", "p.value")[1:ncol(co)]
-    ret <- fix_data_frame(co, nn)
-
-    if (exponentiate) {
-        # save transformation function for use on confidence interval
-        if (is.null(x$family) ||
-                (x$family$link != "logit" && x$family$link != "log")) {
-            warning(paste("Exponentiating coefficients, but model did not use",
-                          "a log or logit link function"))
-        }
-        trans <- exp
+    
+    nn <- c("estimate", "std.error", "statistic", "p.value")
+    if (is(co, "listof")) {
+        # multiple response variables
+        ret <- plyr::ldply(co, fix_data_frame, nn[1:ncol(co[[1]])],
+                           .id = "response")
+        ret$response <- stringr::str_replace(ret$response, "Response ", "")
     } else {
-        trans <- identity
+        ret <- fix_data_frame(co, nn[1:ncol(co)])
     }
 
-    if (conf.int) {
-        # avoid "Waiting for profiling to be done..." message
-        CI <- suppressMessages(confint(x, level = conf.level))
-        colnames(CI) = c("conf.low", "conf.high")
-        ret <- cbind(ret, trans(unrowname(CI)))
-    }
-    ret$estimate <- trans(ret$estimate)
-
-    ret
+    process_lm(ret, x, conf.int = conf.int, conf.level = conf.level,
+               exponentiate = exponentiate)
 }
 
 
@@ -211,3 +214,53 @@ glance.lm <- function(x, ...) {
     ret <- finish_glance(unrowname(ret), x)
     ret
 }
+
+
+#' @export
+augment.mlm <- function(x, ...) {
+    stop("augment does not support multiple responses")
+}
+
+
+#' @export
+glance.mlm <- function(x, ...) {
+    stop("glance does not support multiple responses")
+}
+
+
+#' helper function to process a tidied lm object
+#' 
+#' Adds a confidence interval, and possibly exponentiates, a tidied
+#' object. Useful for operations shared between lm and biglm.
+#' 
+#' @param ret data frame with a tidied version of a coefficient matrix
+#' @param x an "lm", "glm", "biglm", or "bigglm" object
+#' @param conf.int whether to include a confidence interval
+#' @param conf.level confidence level of the interval, used only if
+#' \code{conf.int=TRUE}
+#' @param exponentiate whether to exponentiate the coefficient estimates
+#' and confidence intervals (typical for logistic regression)
+process_lm <- function(ret, x, conf.int = FALSE, conf.level = .95,
+                       exponentiate = FALSE) {
+    if (exponentiate) {
+        # save transformation function for use on confidence interval
+        if (is.null(x$family) ||
+            (x$family$link != "logit" && x$family$link != "log")) {
+            warning(paste("Exponentiating coefficients, but model did not use",
+                          "a log or logit link function"))
+        }
+        trans <- exp
+    } else {
+        trans <- identity
+    }
+    
+    if (conf.int) {
+        # avoid "Waiting for profiling to be done..." message
+        CI <- suppressMessages(confint(x, level = conf.level))
+        colnames(CI) = c("conf.low", "conf.high")
+        ret <- cbind(ret, trans(unrowname(CI)))
+    }
+    ret$estimate <- trans(ret$estimate)
+    
+    ret
+}
